@@ -51,7 +51,7 @@ class M4bMerge:
         else:
             self.subtitle = None
 
-        if not 'authors' in self.metadata:
+        if 'authors' not in self.metadata:
             raise ValueError("No author in metadata")
 
         # Only use first author/narrator for file names;
@@ -171,13 +171,14 @@ class M4bMerge:
             self.processing_args.append('-v')
         elif level == logging.DEBUG:
             self.processing_args.append('-vvv')
-    
+
     def prepare_output_path(self):
         """
             Parses user input for desired output path.
 
             For example:
-            `author/series_name series_position - title: subtitle (year)/author - title (year)`
+            `author/series_name series_position - title`
+            `: subtitle (year)/author - title (year)`
         """
         # First we need to replace the terms with actual data
         # Author
@@ -216,25 +217,35 @@ class M4bMerge:
             self.remove_tag(key)
 
     def remove_tag(self, tag):
-        config.path_format = re.sub(tag, '', config.path_format).rstrip().strip('-')
+        config.path_format = re.sub(
+            tag, '', config.path_format
+        ).rstrip().strip('-')
 
     def find_bitrate(self, file_input):
         # Divide bitrate by 1k, round up,
         # and return back to 1k divisible for round number.
-        target_bitrate = math.ceil(
-            int(mediainfo(file_input)['bit_rate']) / 1000
-        ) * 1000
-        logging.info(f"Source bitrate: {target_bitrate}")
+        try:
+            target_bitrate = math.ceil(
+                int(mediainfo(file_input)['bit_rate']) / 1000
+            ) * 1000
+            logging.info(f"Source bitrate: {target_bitrate}")
+        except KeyError:
+            logging.warning("Unable to determine bitrate, using default")
+            target_bitrate = ''
 
         return target_bitrate
 
     def find_samplerate(self, file_input):
-        target_samplerate = int(
-            mediainfo(
-                file_input
-            )['sample_rate']
-        )
-        logging.info(f"Source samplerate: {target_samplerate}")
+        try:
+            target_samplerate = int(
+                mediainfo(
+                    file_input
+                )['sample_rate']
+            )
+            logging.info(f"Source samplerate: {target_samplerate}")
+        except KeyError:
+            logging.warning("Unable to determine samplerate, using default")
+            target_samplerate = ''
 
         return target_samplerate
 
@@ -371,10 +382,10 @@ class M4bMerge:
         # If multi-disc, find the extension
         if not self.input_extension:
             selected_input = self.find_multi_disc_extension()
+            selected_input_glob = Path(selected_input).glob('*')
         else:
             selected_input = self.input_path
-
-        selected_input_glob = Path(selected_input).glob('**/*')
+            selected_input_glob = Path(selected_input).glob('**/*')
 
         # Find first file with our extension, to check rates against
         for file in sorted(selected_input_glob):
@@ -400,7 +411,7 @@ class M4bMerge:
         )
         # Now that first sorted directory was found, find it's primary ext
         self.input_extension = helpers.find_extension(
-            selected_input)[1]
+            selected_input)
         logging.debug(
             (f"Guessed multi-disc extension to be:"
                 f" {self.input_extension}")
